@@ -3,7 +3,7 @@ from .basic_crop import FaceCropper
 
 file_id='1h7xPSL8zkcCIi1ewp59PjKq8Mvtx8VQR'
 # download to dg_util/.cache/image_preprocessing/shape_predictor_68_face_landmarks.dat
-landmarks_save_path='../../../.cache/image_preprocessing/shape_predictor_68_face_landmarks.dat'
+landmarks_save_path='.cache/shape_predictor_68_face_landmarks.dat'
 
 def download_file_from_google_drive(id, destination):
     import requests
